"""A python package to stor and manipulate gravitational-wava data
in a conveninet framework.
Part of its classes and methods have been taken from GwPy, by D.McLeod
"""

# set package metadata
__version__ = "0.3.0"
